__author__ = 'sowmya'

from elasticsearch import Elasticsearch
from elasticsearch.helpers import bulk, streaming_bulk
from sls_client.query import *
from sls_client.records import *

def get_record():
	queryString = ''
	response = query(queryString)
	for record in response:
		yield record

es = Elasticsearch([{'host':'perfsonar-dev.es.net'}])
index="perfsonar"
es.create( index=index,
        doc_type='perfsonar_records',
        id='ps_records',
        body={},ignore=409)


for ok, result in streaming_bulk(
        es,
        get_record(),
        index=index,
        doc_type='records',
        chunk_size=50 # keep the batch sizes small for appearances only
    ):
    action, result = result.popitem()
    doc_id = '/%s/records/%s' % (index, result['_id'])
    # process the information from ES whether the document has been
    # successfully indexed
    if not ok:
        print('Failed to %s document %s: %r' % (action, doc_id, result))
    else:
        print(doc_id)






__author__ = 'sowmya'

from sls_client.records import *
from sls_client.query import *

import json

def search(record,text):

    queryRecord = 'type='+record
    response = query(queryRecord)

    queryPattern=''+text

    result=[]
    for record in response:
        if u'ls-host' in record:
            record.pop(u'ls-host')
        for key in record:
            if queryPattern in record[key]:
                result.append(record)
    
    return result


def search_tojson(record,text):
    response = search(record,text)
    json_response = json.dumps(response)
    return json_response



__author__ = 'sowmya'

from sls_client.records import *
from sls_client.query import *
import json
import socket

HOST_NAME='host-name'
GROUP_DOMAINS='group-domains'
RECORD_TYPE = 'record-type'

def search_domains(domain,record_type):

    if(not domain):
        raise Exception("Null Parameter", "Domain is empty.")

    #Try hostname. If it fails, try host name for interface. If that also fails, finally do dns resolution
    queryString = GROUP_DOMAINS+"="+hostname
    if record_type:
        queryString = "&"+RECORD_TYPE+"="+record_type
    response = query(queryString)
    hosts=[]
    if response:
        for record in response:
            hosts.append(record['host-name'])

    for host in hosts:
        admin = __get_admin_info(host)
        host[HOST_ADMINISTRATORS] = admin

    return hosts


def get_host_info_json(domain,record_type):
    hostlist = search_domains(hostname)
    result={}
    result["host"] = []
    result["search-query"] = 
    if(hostlist):
        result["host"] = hostlist

    json_output = json.dumps(result)
    return json_output
